@@ -1,21 +1,24 @@
+/* -*-mode:c++; c-file-style: "gnu";-*- */
 /*
- *  $Id: cookie.cpp,v 1.3 2002/03/03 17:41:44 sbooth Exp $
+ *  $Id: cookie.cpp,v 1.10 2007/07/02 18:48:19 sebdiaz Exp $
  *
- *  Copyright (C) 1996 - 2002 Stephen F. Booth
+ *  Copyright (C) 1996 - 2004 Stephen F. Booth <sbooth@gnu.org>
+ *                       2007 Sebastien DIAZ <sebastien.diaz@gmail.com>
+ *  Part of the GNU cgicc library, http://www.gnu.org/software/cgicc
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 3 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA 
  */
 
 /*! \file cookie.cpp
@@ -36,7 +39,7 @@
 #include "cgicc/HTTPHTMLHeader.h"
 #include "cgicc/HTMLClasses.h"
 
-#if HAVE_UNAME
+#if HAVE_SYS_UTSNAME_H
 #  include <sys/utsname.h>
 #endif
 
@@ -44,20 +47,37 @@
 #  include <sys/time.h>
 #endif
 
-// To use logging, the variable gLogFile MUST be defined, and it _must_
-// be an ofstream
-#if DEBUG
-  STDNS ofstream gLogFile( "/change_this_path/cgicc.log", STDNS ios::app );
-#endif
+#include "styles.h"
 
-#if CGICC_USE_NAMESPACES
-  using namespace std;
-  using namespace cgicc;
-#else
-#  define div div_
-#  define link link_
-#  define select select_
-#endif
+using namespace std;
+using namespace cgicc;
+
+// Print the form for this CGI
+void
+printForm(const Cgicc& cgi)
+{
+  cout << "<form method=\"post\" action=\"" 
+       << cgi.getEnvironment().getScriptName() << "\">" << endl;
+    
+  cout << "<table>" << endl;
+
+  cout << "<tr><td class=\"title\">Cookie Name</td>"
+       << "<td class=\"form\">"
+       << "<input type=\"text\" name=\"name\" />"
+       << "</td></tr>" << endl;
+
+  cout << "<tr><td class=\"title\">Cookie Value</td>"
+       << "<td class=\"form\">"
+       << "<input type=\"text\" name=\"value\" />"
+       << "</td></tr>" << endl;
+
+  cout << "</table>" << endl;
+
+  cout << "<div class=\"center\"><p>"
+       << "<input type=\"submit\" name=\"submit\" value=\"Set the cookie\" />"
+       << "<input type=\"reset\" value=\"Nevermind\" />"
+       << "</p></div></form>" << endl;
+}
 
 // Main Street, USA
 int
@@ -96,34 +116,11 @@ main(int /*argc*/,
 
     // Output the style sheet portion of the header
     cout << style() << comment() << endl;
-    cout << "body { color: black; background-color: white; }" << endl;
-    cout << "hr.half { width: 60%; align: center; }" << endl;
-    cout << "span.red, strong.red { color: red; }" << endl;
-    cout << "div.smaller { font-size: small; }" << endl;
-    cout << "div.notice { border: solid thin; padding: 1em; margin: 1em 0; "
-	 << "background: #ddd; }" << endl;
-    cout << "span.blue { color: blue; }" << endl;
-    cout << "col.title { color: white; background-color: black; ";
-    cout << "font-weight: bold; text-align: center; }" << endl;
-    cout << "col.data { background-color: #ddd; text-align: left; }" << endl;
-    cout << "td.data, TR.data { background-color: #ddd; text-align: left; }"
-	 << endl;
-    cout << "td.grayspecial { background-color: #ddd; text-align: left; }"
-	 << endl;
-    cout << "td.ltgray, tr.ltgray { background-color: #ddd; }" << endl;
-    cout << "td.dkgray, tr.dkgray { background-color: #bbb; }" << endl;
-    cout << "col.black, td.black, td.title, tr.title { color: white; " 
-	 << "background-color: black; font-weight: bold; text-align: center; }"
-	 << endl;
-    cout << "col.gray, td.gray { background-color: #ddd; text-align: center; }"
-	 << endl;
-    cout << "table.cgi { left-margin: auto; right-margin: auto; width: 90%; }"
-	 << endl;
-
+    cout << styles;
     cout << comment() << style() << endl;
 
     cout << title() << "GNU cgicc v" << cgi.getVersion() 
-	 << " HTTPCookie Results" << title() << endl;
+	 << " HTTPCookie" << title() << endl;
 
     cout << head() << endl;
     
@@ -155,36 +152,23 @@ main(int /*argc*/,
     // Show the cookie info from the environment
     cout << h2("Cookie Information from the Environment") << endl;
   
-    cout << CGICCNS div().set("align","center") << endl;
+    cout << cgicc::div().set("align","center") << endl;
     
-    cout << table().set("border","0").set("rules","none").set("frame","void")
-      .set("cellspacing","2").set("cellpadding","2")
-      .set("class","cgi") << endl;
-    cout << colgroup().set("span","2") << endl;
-    cout << col().set("align","center").set("class","title").set("span","1") 
-	 << endl;
-    cout << col().set("align","left").set("class","data").set("span","1") 
-	 << endl;
-    cout << colgroup() << endl;
+    cout << table() << endl;
     
     cout << tr() << td("HTTPCookie").set("class","title")
 	 << td(env.getCookies()).set("class","data") << tr() << endl;
     
-    cout << table() << CGICCNS div() << endl;
+    cout << table() << cgicc::div() << endl;
 
 
     // Show the cookie info from the cookie list
     cout << h2("HTTP Cookies via vector") << endl;
   
-    cout << CGICCNS div().set("align","center") << endl;
+    cout << cgicc::div().set("align","center") << endl;
   
-    cout << table().set("border","0").set("rules","none").set("frame","void")
-      .set("cellspacing","2").set("cellpadding","2")
-      .set("class","cgi") << endl;
-    cout << colgroup().set("span","2") << endl;
-    cout << col().set("align","center").set("span","2") << endl;
-    cout << colgroup() << endl;
-    
+    cout << table() << endl;
+
     cout << tr().set("class","title") << td("Cookie Name") 
 	 << td("Cookie Value") << tr() << endl;
     
@@ -196,17 +180,16 @@ main(int /*argc*/,
       cout << tr().set("class","data") << td(iter->getName()) 
 	   << td(iter->getValue()) << tr() << endl;
     }
-    cout << table() << CGICCNS div() << endl;
+    cout << table() << cgicc::div() << endl;
     
 
-    // Now print out a footer with some fun info
-    cout << p() << CGICCNS div().set("align","center");
-    cout << a("Back to form").set("href", cgi.getEnvironment().getReferrer()) 
-	 << endl;
-    cout << CGICCNS div() << br() << hr(set("class","half")) << endl;
+    // Print out the form to do it again
+    cout << br() << endl;
+    printForm(cgi);
+    cout << hr().set("class", "half") << endl;
     
     // Information on cgicc
-    cout << CGICCNS div().set("align","center").set("class","smaller") << endl;
+    cout << cgicc::div().set("align","center").set("class","smaller") << endl;
     cout << "GNU cgi" << span("cc").set("class","red") << " v";
     cout << cgi.getVersion() << br() << endl;
     cout << "Compiled at " << cgi.getCompileTime();
@@ -232,11 +215,11 @@ main(int /*argc*/,
       + (end.tv_usec - start.tv_usec);
 
     cout << br() << "Total time for request = " << us << " us";
-    cout << " (" << (double) (us/1000000.0) << " s)";
+    cout << " (" << static_cast<double>(us/1000000.0) << " s)";
 #endif
 
     // End of document
-    cout << CGICCNS div() << endl;
+    cout << cgicc::div() << endl;
     cout << body() << html() << endl;
 
     // No chance for failure in this example
@@ -244,7 +227,7 @@ main(int /*argc*/,
   }
 
   // Did any errors occur?
-  catch(const STDNS exception& e) {
+  catch(const std::exception& e) {
 
     // This is a dummy exception handler, as it doesn't really do
     // anything except print out information.
@@ -254,7 +237,7 @@ main(int /*argc*/,
     html::reset(); 	head::reset(); 		body::reset();
     title::reset(); 	h1::reset(); 		h4::reset();
     comment::reset(); 	td::reset(); 		tr::reset(); 
-    table::reset();	CGICCNS div::reset(); 	p::reset(); 
+    table::reset();	cgicc::div::reset(); 	p::reset(); 
     a::reset();		h2::reset(); 		colgroup::reset();
 
     // Output the HTTP headers for an HTML document, and the HTML 4.0 DTD info
@@ -283,12 +266,12 @@ main(int /*argc*/,
     cout << h1() << "GNU cgi" << span("cc", set("class","red"))
 	 << " caught an exception" << h1() << endl; 
   
-    cout << CGICCNS div().set("align","center").set("class","notice") << endl;
+    cout << cgicc::div().set("align","center").set("class","notice") << endl;
 
     cout << h2(e.what()) << endl;
 
     // End of document
-    cout << CGICCNS div() << endl;
+    cout << cgicc::div() << endl;
     cout << hr().set("class","half") << endl;
     cout << body() << html() << endl;
     
